/*--------------------------------------------------------------------------------------------------------
                                    AVR ADC library.

Filename: adc.c
Controller: Atmega8/16/32/128
Oscillator: 11.0592 MHz
Author: XploreLabz
website: www.xplorelabz.com
Reference:Atmega32 dataSheet
--------------------------------------------------------------------------------------------------------*/
#include<avr/io.h>
#include <util/delay.h>
#include "adc.h"


/*----------------------------------------------------------------------------------
                         void ADC_Init()
 -----------------------------------------------------------------------------------
 * I/P Arguments: none.
 * Return value	: none

 * description :This function initializes the ADC control registers
-----------------------------------------------------------------------------------*/
void ADC_Init()
 {
   ADCSRA=0x81; //Enable ADC , sampling freq=osc_freq/2
   ADMUX=0x00; //Result right justified, select channel zero
  }


/*----------------------------------------------------------------------------------
                 unsignaed int ADC_StartConversion(unsigned char channel)
 -----------------------------------------------------------------------------------
 * I/P Arguments: char(channel number).
 * Return value	: int(10 bit ADC result)

 * description  :This function does the ADC conversioin for the Selected Channel
                 and returns the converted 10bit result
------------------------------------------------------------------------------------*/				 
unsigned int ADC_StartConversion(unsigned char channel)
 {
   
   ADMUX=channel; //Select a channel
   _delay_ms(5);   //Wait till the channel is selected
   
   ADCSRA=0xc1;   //Start the ADC conversion by setting ADSC bit
   
   while((ADCSRA & (1<<ADIF))==0); //Wait till the conversion is over
                                  //ADIF will be set once ADC conversion is complete
     return(ADCW);                //Return the 10-bit result
   }
       
